==> haskell-time-manager-0.0.1-145.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-JLWrHaSTuhLLhgQpXh0DRR
key:                  time-manager-0.0.1-JLWrHaSTuhLLhgQpXh0DRR
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  bea5774086bf13d1077c032afe709c5b
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/loongarch64-linux-ghc-9.6.6/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-JLWrHaSTuhLLhgQpXh0DRR
depends:
    auto-update-0.1.6-9ryA5SLAC8xHZnIgVWhrWD base-4.18.2.1
    unliftio-0.2.25.1-IdlKKcTSqjp7zAgGJLE7Xd

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-manager-0.0.1-146-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-J7X2oj44VWZ1BlIeM6DdG7
key:                  time-manager-0.0.1-J7X2oj44VWZ1BlIeM6DdG7
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  6fefc60139b016ee1fa21b4da1240fed
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/loongarch64-linux-ghc-9.6.6/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-J7X2oj44VWZ1BlIeM6DdG7
depends:
    auto-update-0.1.6-88T3ReDBoup7kx6uceSFG6 base-4.18.2.1
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
